@@ -17,6 +17,11 @@ from . import event_levels
 from . import event_categories
 from . import events
 from . import timeseries_by_events
+from . import events_by_sites
+from . import events_by_buildings
+from . import events_by_storeys
+from . import events_by_spaces
+from . import events_by_zones
 from . import sites
 from . import buildings
 from . import storeys
@@ -67,6 +72,11 @@ MODULES = (
     event_categories,
     events,
     timeseries_by_events,
+    events_by_sites,
+    events_by_buildings,
+    events_by_storeys,
+    events_by_spaces,
+    events_by_zones,
     sites,
     buildings,
     storeys,
